LcFillRule enum

How overlapping/self-intersecting regions of a PathLayer are filled (mirrors lib/src/model/path.dart's FillRule). Only meaningful for fills; ignored for a stroke-only paint.

Inheritance
Available extensions

Values

LC_FILL_RULE_NON_ZERO → const LcFillRule
const LcFillRule(0)
LC_FILL_RULE_EVEN_ODD → const LcFillRule
const LcFillRule(1)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromValue(int value) → LcFillRule

Constants

values → const List<LcFillRule>
A constant List of the values in this enum, in order of their declaration.