lc_font_unregister function

  1. @Native<Int32 Function(Pointer<Char>, Int32)>(ffi.Pointer<ffi.Char>, ffi.Int32)>()
int lc_font_unregister(
  1. Pointer<Char> name,
  2. int weight
)

Removes the font previously registered under name+weight. Returns 0 if found and removed, 1 if no font was registered under that exact name+weight pair. Other weights registered under the same name are unaffected.

Implementation

@ffi.Native<ffi.Int32 Function(ffi.Pointer<ffi.Char>, ffi.Int32)>()
external int lc_font_unregister(ffi.Pointer<ffi.Char> name, int weight);