LcGradientStop class final

A single color stop within a gradient's ramp. offset is 0..1 along the gradient (mirrors lib/src/model/gradient.dart's GradientStop).

Inheritance
Implemented types
Available extensions

Constructors

LcGradientStop()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
color_argb int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
offset double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited