LcStrokeCap enum
Shape of a stroke's open ends (mirrors lib/src/model/paint.dart's StrokeCap, same declared order). Only meaningful for a stroked paint.
Values
- LC_STROKE_CAP_BUTT → const LcStrokeCap
-
const LcStrokeCap(0) - LC_STROKE_CAP_ROUND → const LcStrokeCap
-
const LcStrokeCap(1) - LC_STROKE_CAP_SQUARE → const LcStrokeCap
-
const LcStrokeCap(2)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → LcStrokeCap
Constants
-
values
→ const List<
LcStrokeCap> - A constant List of the values in this enum, in order of their declaration.